@@ -66,13 +66,17 @@ md.pattern <- function(x, plot = FALSE)
 #' md_pattern(bfi)
 #' md_pattern(bfi, omit_complete = FALSE, min_freq = 0.2)
 md_pattern <- function(data, omit_complete = TRUE, min_freq = 0.01) {
-  if (sum(is.na(data)) == 0) {
-    message("No missing values.")
-  } else {
-    for (i in seq_along(names(data))) {
-      # mice::md.pattern coerces character/factor to NA
+  for (i in seq_along(names(data))) {
+    # mice::md.pattern coerces character/factor to NA
+    if(!is.numeric(data[[i]])) {
       data[[i]] <- as.numeric(as.factor(data[[i]]))
     }
+  }
+  if (sum(is.na(data)) == 0) {
+    message("No missing values.")
+  } else if (ncol(data) == 1) {
+    message("Only one column.")
+  } else {
     md_pattern <- suppressMessages(md.pattern(data, plot = FALSE))
     n_miss <- rownames(md_pattern)
     if (is.null(n_miss)) {
@@ -166,14 +170,16 @@ modified <- function(survey, variable = "modified") {
 
 export_table <- function(df) {
   if(requireNamespace("DT", quietly = TRUE)) {
-    DT::datatable(df, filter = "top", extensions = 'Buttons',
+    DT::formatSignif(DT::datatable(df,
+                  filter = "top", extensions = 'Buttons',
                   escape = FALSE,
                   rownames = FALSE,
                   options = list(
                     dom = 'Bfrtip',
                     buttons = c('copy', 'csv', 'excel', 'pdf', 'print'),
                     pageLength = 200
-                  ))
+                  )), intersect(names(df), c("complete_rate",
+                                                 "mean", "sd")))
   } else {
     knitr::kable(df)
   }
@@ -217,3 +223,19 @@ is_numeric_or_time_var <- function(x) {
     inherits(x, c("POSIXt", "POSIXct", "POSIXlt", "Date")) ||
     methods::is(x, "Timespan")
 }
+
+futureAssignToEnv <- function(name, value, env) {
+  expr <- substitute(value)
+  future::futureAssign(name, expr, envir = env, seed = TRUE, substitute = F)
+}
+# futureAssignOrFallback("blu", rnorm(1), x)
+# x$blu
+# futureAssignOrFallback("ble", rnorm(1), x)
+# x$ble
+
+
+library(future)
+e <- new.env()
+e$a %<-% rnorm(1) %seed% TRUE
+e$b %<-% rnorm(1) %seed% TRUE
+e$a==e$b
